<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:owl="http://www.w3.org/2002/07/owl#"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
	version="1.0">

<xsl:output method="xml"
	version="1.0"
	encoding="utf-8"
	omit-xml-declaration="no"
	doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
	doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
	indent="yes" />

<xsl:variable name="xmlbase" select="/rdf:RDF/@xml:base" />

<xsl:template match="/rdf:RDF">

<html xmlns="http://www.w3.org/1999/xhtml" 
	xml:lang="en">
<head>
	<title><xsl:value-of select="owl:Ontology/rdfs:label" /></title>
	<meta http-equiv="Content-Type" content="text/html;charset=utf-8"><xsl:comment /></meta>
	<link href="http://viaf.org/viaf/css/xmlns-style.css" rel="stylesheet"  type="text/css" ><xsl:comment/></link>
	<link href="http://viaf.org/viaf/css/owl-style.css" rel="stylesheet"  type="text/css" ><xsl:comment /></link>
</head>

<body>
	<h1><xsl:value-of select="owl:Ontology/rdfs:label" /></h1>
	
	<h2>Namespace Document - v <xsl:value-of select="owl:Ontology/owl:versionInfo" /></h2>

	<dl>
		<dt>This version:</dt>
		<dd><xsl:value-of select="@xml:base" /><xsl:value-of select="owl:Ontology[@rdf:about='#current']/owl:backwardCompatibleWith/@rdf:resource" /></dd>
	</dl>
	<dl>
		<xsl:if test="owl:Ontology/owl:priorVersion">
		<dt>Previous version:</dt>
		<dd><a href="{owl:Ontology/owl:priorVersion/@rdf:resource}"><xsl:value-of select="owl:Ontology/owl:priorVersion/@rdf:resource" /></a></dd>
		</xsl:if>
		
	</dl>

	<hr />

  <div class="status">
  	<h2>Note</h2>
  	<p>View the source in your browser to see the underlying OWL</p>
    <h2>Status of This Document</h2>
    <p>Hypothetical</p>
    
	<a id="sec-glance"></a>
	<h2 id="glance">At a glance</h2>
 
	<p>
An index of terms, by class and by property.
	</p>
 
	<div class="azlist">

	<p>Classes: |
<xsl:for-each select="owl:Class[not(starts-with(@rdf:about, 'http://'))]">
	<xsl:sort select="@rdf:about" />
	<a href="{@rdf:about}" title="{rdfs:label}"><xsl:value-of select="substring-after(@rdf:about,'#')" /></a> |
</xsl:for-each> 
	</p>

<p>Datatype Properties: |
<xsl:for-each select="owl:DatatypeProperty[not(starts-with(@rdf:about, 'http://'))]">
	<xsl:sort select="@rdf:about" />
<a href="{@rdf:about}" title="{rdfs:label}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a> |
</xsl:for-each>
</p>

<p>Object Properties: |
<xsl:for-each select="owl:ObjectProperty[not(starts-with(@rdf:about, 'http://'))]">
	<xsl:sort select="@rdf:about" />
<a href="{@rdf:about}" title="{rdfs:label}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a> |
</xsl:for-each>
</p>
</div>

  </div>

  <div style="clear: left;"></div>

<!-- and this is the bulk of the vocab descriptions -->
<div class="termlist">
<h3>Classes and Properties</h3>
<div class='termdetails'>

<h2>Classes</h2>
<xsl:for-each select="owl:Class[not(starts-with(@rdf:about, 'http://'))]">
	<xsl:sort select="@rdf:about" />
	<xsl:variable name="about" select="@rdf:about" />
	<div class="specterm" id="{substring-after(@rdf:about, '#')}" about="{@rdf:about}" typeof="owl:Class">
		<h3>Class: <xsl:value-of select="substring-after(@rdf:about, '#')" /></h3> 
            <table>
            	<xsl:if test="rdfs:subClassOf">
            	<tr>
            		<th>Subclass of:</th>
            		<td>
            			<ul>
            			<xsl:for-each select="rdfs:subClassOf">
            			<li><a href="{@rdf:resource}"><xsl:value-of select="substring(@rdf:resource, 2)" /></a></li>
            			</xsl:for-each>
            			</ul>
            		</td>
            	</tr>
            	</xsl:if>
            	<xsl:if test="rdfs:label">
            	<tr>
            		<th>Label:</th>
            		<td>
		            	<xsl:value-of select="rdfs:label"/>
            		</td>
            	</tr>
            	</xsl:if>
            	<xsl:if test="rdfs:comment">
            	<tr>
            		<th>Comment:</th>
            		<td>
		            	<xsl:value-of select="rdfs:comment"/>
            		</td>
            	</tr>
            	</xsl:if>
				<xsl:if test="count(/rdf:RDF/owl:DatatypeProperty[rdfs:domain/@rdf:resource=$about])">
            	<tr>
            		<th>Datatype properties:</th>
 					<td>
 						<ul>
 						<xsl:for-each select="/rdf:RDF/owl:DatatypeProperty[rdfs:domain/@rdf:resource=$about]">
							<li><a href="{@rdf:about}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a></li>
 						</xsl:for-each>
 						</ul>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="count(/rdf:RDF/owl:ObjectProperty[rdfs:domain/@rdf:resource=$about])">
            	<tr>
            		<th>Specified as domain of:</th>
 					<td>
 						<ul>
 						<xsl:for-each select="/rdf:RDF/owl:ObjectProperty[rdfs:domain/@rdf:resource=$about]">
 							<li><a href="{@rdf:about}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a></li>
 						</xsl:for-each>
 						</ul>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="count(/rdf:RDF/owl:ObjectProperty[rdfs:range/@rdf:resource=$about])">
            	<tr>
            		<th>Specified as range of:</th>
					<td>
						<ul>
 						<xsl:for-each select="/rdf:RDF/owl:ObjectProperty[rdfs:range/@rdf:resource=$about]">
 							<li><a href="{@rdf:about}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a></li>
 						</xsl:for-each>
						</ul>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="count(/rdf:RDF/owl:Class[rdfs:subClassOf/@rdf:resource=$about])">
				<tr>
					<th>Subclasses:</th>
					<td>
						<ul>
						<xsl:for-each select="/rdf:RDF/owl:Class[rdfs:subClassOf/@rdf:resource=$about]">
							<li><a href="{@rdf:about}"><xsl:value-of select="substring-after(@rdf:about, '#')" /></a></li>
						</xsl:for-each>
						</ul>
					</td>
				</tr>
				</xsl:if>
				<xsl:if test="count(owl:disjointWith)">
				<tr>
					<th>Disjoint With:</th>
					<td>
						<ul>
						<xsl:for-each select="owl:disjointWith">
							<xsl:variable name="resource" select="@rdf:resource" />
							<span rel="owl:disjointWith" href="{owl:disjointWith}">
								<li><a href="{@rdf:resource}"><xsl:value-of select="substring-after(/rdf:RDF/owl:Class[@rdf:about=$resource]/@rdf:about, '#')" /></a></li>
							</span>
						</xsl:for-each>
						</ul>
					</td>
				</tr>
				</xsl:if>
            </table>

<!-- todo: write rdfs:domain statements for those properties -->

            <p style="float: right; font-size: small;">[<a href="{@rdf:about}">#</a>]</p>
            <br/>
            </div>
</xsl:for-each>

<h2>Properties</h2>
<xsl:for-each select="owl:DatatypeProperty[not(starts-with(@rdf:about, 'http://'))] | owl:ObjectProperty[not(starts-with(@rdf:about, 'http://'))]">
	<xsl:sort select="@rdf:about" />
	<div class="specterm" id="{substring-after(@rdf:about, '#')}" about="{@rdf:about}" typeof="rdf:Property">
		<h3><xsl:value-of select="local-name()" />: <xsl:value-of select="substring-after(@rdf:about, '#')" /></h3> 
		<table>
			<xsl:if test="rdfs:label">
			<tr>
				<th>Label:</th>
				<td>
					<xsl:value-of select="rdfs:label" />
				</td>
			</tr>
			</xsl:if>
			<xsl:if test="rdfs:comment">
			<tr>
				<th>Comment:</th>
				<td>
					<xsl:value-of select="rdfs:comment" />
				</td>
			</tr>
			</xsl:if>
            <tr>
            	<th>Domain:</th>
 				<td>
 					<xsl:variable name="resource" select="rdfs:domain/@rdf:resource" />
 					<span rel="rdfs:domain" href="{$resource}">
 						<xsl:choose>
 							<xsl:when test="starts-with($resource, 'http://')">
	 						<a href="{$resource}"><xsl:value-of select="$resource" /></a>
 							</xsl:when>
 							<xsl:otherwise>
	 						<a href="{$resource}"><xsl:value-of select="substring-after(/rdf:RDF/owl:Class[@rdf:about=$resource]/@rdf:about, '#')" /></a>
 							</xsl:otherwise>
 						</xsl:choose>
 					</span>
				</td>
			</tr>
            <tr>
            	<th>Range:</th>
				<td>
 					<xsl:variable name="resource" select="rdfs:range/@rdf:resource" />
 					<span rel="rdfs:range" href="{$resource}">
 						<xsl:choose>
 							<xsl:when test="starts-with($resource,'http://')">
	 						<a href="{$resource}"><xsl:value-of select="$resource" /></a>
 							</xsl:when>
 							<xsl:otherwise>
	 						<a href="{$resource}"><xsl:value-of select="substring-after(/rdf:RDF/owl:Class[@rdf:about=$resource]/@rdf:about, '#')" /></a>
 							</xsl:otherwise>
 						</xsl:choose>
 					</span>
				</td>
			</tr>
			<tr>
				<td>
					<span rel="rdfs:isDefinedBy" href="http://xmlns.com/viaf/0.1/" />
				</td>
			</tr>
			<xsl:if test="owl:inverseOf">
			<tr>
				<th>Inverse Of:</th>
				<td>
					<xsl:variable name="resource" select="owl:inverseOf/@rdf:resource" />
					<span rel="owl:inverseOf" href="{$resource}">
						<a href="{$resource}"><xsl:value-of select="substring-after(/rdf:RDF/*[@rdf:about=$resource]/@rdf:about, '#')" /></a>
					</span>
				</td>
			</tr>
			</xsl:if>
		</table>
            <p style="float: right; font-size: small;">[<a href="{@rdf:about}">#</a>]</p>

            <br/>
            </div>
</xsl:for-each>
</div>
</div>
</body>
</html>

</xsl:template>

</xsl:stylesheet>
